@@ -55,6 +55,7 @@ export const stubAllWorkspacesLimit = 1;
 export const stubWorkspaceInactivityTimeout = 0;
 export const stubWorkspaceRunTimeout = 0;
 export const stubWorkspaceStartupTimeout = 0;
+export const stubAxiosRequestTimeout = 0;
 export const defaultPluginRegistryUrl = 'http://plugin-registry.eclipse-che.svc/v3';
 export const internalRegistryDisableStatus = true;
 export const externalDevfileRegistries = [{ url: 'https://devfile.registry.test.org/' }];
@@ -181,6 +182,7 @@ export const getDevWorkspaceClient = jest.fn(
         getWorkspaceInactivityTimeout: _cheCustomResource => stubWorkspaceInactivityTimeout,
         getWorkspaceRunTimeout: _cheCustomResource => stubWorkspaceRunTimeout,
         getWorkspaceStartTimeout: _cheCustomResource => stubWorkspaceStartupTimeout,
+        getAxiosRequestTimeout: () => stubAxiosRequestTimeout,
         getDefaultPluginRegistryUrl: _cheCustomResource => defaultPluginRegistryUrl,
         getExternalDevfileRegistries: _cheCustomResource => externalDevfileRegistries,
         getInternalRegistryDisableStatus: _cheCustomResource => internalRegistryDisableStatus,
