@@ -37,6 +37,7 @@ import {
 import { buildFactoryLocation } from '@/services/helpers/location';
 import { AlertItem } from '@/services/helpers/types';
 import { che } from '@/services/models';
+import { DEVWORKSPACE_BOOTSTRAP } from '@/services/workspace-client/devworkspace/devWorkspaceClient';
 import { AppThunk } from '@/store';
 import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
 import { MockStoreBuilder } from '@/store/__mocks__/mockStore';
@@ -78,6 +79,9 @@ const devfile = {
   },
 } as devfileApi.Devfile;
 
+// mute console.error
+console.error = jest.fn();
+
 describe('Creating steps, applying a devfile', () => {
   let searchParams: URLSearchParams;
   let factoryId: string;
@@ -238,13 +242,18 @@ describe('Creating steps, applying a devfile', () => {
         expect(prepareDevfile).toHaveBeenCalledWith(
           expect.objectContaining({
             attributes: {
-              'controller.devfile.io/bootstrap-devworkspace': true,
+              [DEVWORKSPACE_BOOTSTRAP]: true,
               defaultDevfile: true,
+              'dw.metadata.annotations': {
+                'che.eclipse.org/devfile':
+                  'schemaVersion: 2.1.0\nmetadata:\n  generateName: empty\nattributes:\n  defaultDevfile: true\n',
+              },
             },
           }),
           factoryId,
           undefined,
           false,
+          undefined,
         ),
       );
       await waitFor(() => expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalled());
@@ -328,12 +337,13 @@ describe('Creating steps, applying a devfile', () => {
         expect(prepareDevfile).toHaveBeenCalledWith(
           expect.objectContaining({
             attributes: {
-              'controller.devfile.io/bootstrap-devworkspace': true,
+              [DEVWORKSPACE_BOOTSTRAP]: true,
             },
           }),
           factoryId,
           undefined,
           false,
+          undefined,
         ),
       );
       await waitFor(() => expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalled());
@@ -404,12 +414,17 @@ describe('Creating steps, applying a devfile', () => {
           expect.objectContaining({
             attributes: {
               defaultDevfile: true,
-              'controller.devfile.io/bootstrap-devworkspace': true,
+              'dw.metadata.annotations': {
+                'che.eclipse.org/devfile':
+                  'schemaVersion: 2.1.0\nmetadata:\n  generateName: empty\nattributes:\n  defaultDevfile: true\n',
+              },
+              [DEVWORKSPACE_BOOTSTRAP]: true,
             },
           }),
           factoryId,
           undefined,
           false,
+          undefined,
         ),
       );
       await waitFor(() => expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalled());
@@ -483,11 +498,16 @@ describe('Creating steps, applying a devfile', () => {
           expect.objectContaining({
             attributes: {
               defaultDevfile: true,
+              'dw.metadata.annotations': {
+                'che.eclipse.org/devfile':
+                  'schemaVersion: 2.1.0\nmetadata:\n  generateName: empty\nattributes:\n  defaultDevfile: true\n',
+              },
             },
           }),
           factoryId,
           undefined,
           false,
+          undefined,
         ),
       );
       await waitFor(() => expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalled());
@@ -511,7 +531,7 @@ describe('Creating steps, applying a devfile', () => {
       await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
 
       await waitFor(() =>
-        expect(prepareDevfile).toHaveBeenCalledWith(devfile, factoryId, undefined, true),
+        expect(prepareDevfile).toHaveBeenCalledWith(devfile, factoryId, undefined, true, undefined),
       );
     });
 
@@ -534,7 +554,7 @@ describe('Creating steps, applying a devfile', () => {
       await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
 
       await waitFor(() =>
-        expect(prepareDevfile).toHaveBeenCalledWith(devfile, factoryId, undefined, true),
+        expect(prepareDevfile).toHaveBeenCalledWith(devfile, factoryId, undefined, true, undefined),
       );
     });
 
@@ -554,7 +574,13 @@ describe('Creating steps, applying a devfile', () => {
       await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
 
       await waitFor(() =>
-        expect(prepareDevfile).toHaveBeenCalledWith(devfile, factoryId, undefined, false),
+        expect(prepareDevfile).toHaveBeenCalledWith(
+          devfile,
+          factoryId,
+          undefined,
+          false,
+          undefined,
+        ),
       );
     });
   });
@@ -679,7 +705,7 @@ describe('Creating steps, applying a devfile', () => {
       expect(mockOnNextStep).not.toHaveBeenCalled();
       expect(mockOnError).not.toHaveBeenCalled();
 
-      expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalledTimes(1);
+      await waitFor(() => expect(mockCreateWorkspaceFromDevfile).toHaveBeenCalledTimes(1));
     });
 
     test('action callback to continue with default devfile', async () => {
