@@ -31,8 +31,10 @@ export function prepareDevfile(
   factoryId: string,
   storageType: che.WorkspaceStorageType | undefined,
   appendSuffix: boolean,
+  _parentDevfile?: devfileApi.Devfile | undefined,
 ): devfileApi.Devfile {
   const devfile = cloneDeep(_devfile);
+  const parentDevfile = cloneDeep(_parentDevfile);
   const attributes = DevfileAdapter.getAttributes(devfile);
   if (
     !attributes[DEVWORKSPACE_METADATA_ANNOTATION] ||
@@ -60,8 +62,15 @@ export function prepareDevfile(
   devfile.metadata.name = sanitizeName(devfile.metadata.name);
 
   // propagate storage type
-  if (storageType === 'ephemeral') {
-    attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR] = 'ephemeral';
+  if (storageType) {
+    attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR] = storageType;
+  }
+  if (parentDevfile && attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR]) {
+    const parentDevfileAttributes = DevfileAdapter.getAttributes(parentDevfile);
+    if (parentDevfileAttributes[DEVWORKSPACE_STORAGE_TYPE_ATTR]) {
+      delete attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR];
+      console.warn(`Unable to apply ${DEVWORKSPACE_STORAGE_TYPE_ATTR} attribute.`);
+    }
   }
 
   return devfile;
