@@ -10,12 +10,11 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { V230DevfileMetadata } from 'devfile-api';
+import { V230DevfileMetadata } from '@devfile/api';
 
 export type DevfileMetadataLike = V230DevfileMetadata & {
   namespace?: string;
   generateName?: string;
 };
 
-export type DevfileMetadata = DevfileMetadataLike &
-  Required<Pick<DevfileMetadataLike, 'name' | 'namespace'>>;
+export type DevfileMetadata = DevfileMetadataLike & Required<Pick<DevfileMetadataLike, 'name'>>;
