@@ -33,22 +33,20 @@ import {
 import {
   DEVWORKSPACE_CONFIG_ATTR,
   DEVWORKSPACE_CONTAINER_BUILD_ATTR,
-  DEVWORKSPACE_STORAGE_TYPE_ATTR,
 } from '@/services/devfileApi/devWorkspace/spec/template';
 import { delay } from '@/services/helpers/delay';
 import { isWebTerminal } from '@/services/helpers/devworkspace';
 import { DevWorkspaceStatus } from '@/services/helpers/types';
 import { fetchData } from '@/services/registry/fetchData';
 import { WorkspaceAdapter } from '@/services/workspace-adapter';
-import {
-  devWorkspaceApiGroup,
-  devWorkspaceSingularSubresource,
-  devWorkspaceVersion,
-} from '@/services/workspace-client/devworkspace/converters';
 import { DevWorkspaceDefaultPluginsHandler } from '@/services/workspace-client/devworkspace/DevWorkspaceDefaultPluginsHandler';
 import { EDITOR_DEVFILE_API_QUERY } from '@/store/DevfileRegistries/const';
 import { WorkspacesDefaultPlugins } from '@/store/Plugins/devWorkspacePlugins';
 
+export const devWorkspaceVersion = 'v1alpha2';
+export const devWorkspaceApiGroup = 'workspace.devfile.io';
+export const devWorkspaceSingularSubresource = 'devworkspace';
+
 export const COMPONENT_UPDATE_POLICY = 'che.eclipse.org/components-update-policy';
 export const REGISTRY_URL = 'che.eclipse.org/plugin-registry-url';
 
@@ -56,6 +54,8 @@ export const DEVWORKSPACE_NEXT_START_ANNOTATION = 'che.eclipse.org/next-start-cf
 
 export const DEVWORKSPACE_DEBUG_START_ANNOTATION = 'controller.devfile.io/debug-start';
 
+export const DEVWORKSPACE_BOOTSTRAP = 'controller.devfile.io/bootstrap-devworkspace';
+
 export const DEVWORKSPACE_DEVFILE_SOURCE = 'che.eclipse.org/devfile-source';
 
 export const DEVWORKSPACE_DEVFILE = 'che.eclipse.org/devfile';
@@ -215,7 +215,7 @@ export class DevWorkspaceClient {
       {
         op: 'replace',
         path: '/spec/template/components',
-        value: devWorkspace.spec.template.components,
+        value: devWorkspace.spec.template.components || [],
       },
     ]);
   }
@@ -463,26 +463,6 @@ export class DevWorkspaceClient {
       }
     }
 
-    const currentPvcStrategy = config.defaults.pvcStrategy;
-    if (currentPvcStrategy) {
-      const devworkspaceStorageTypePath = `/spec/template/attributes/${this.escape(
-        DEVWORKSPACE_STORAGE_TYPE_ATTR,
-      )}`;
-
-      if (attributes) {
-        if (!attributes[DEVWORKSPACE_STORAGE_TYPE_ATTR]) {
-          patch.push({ op: 'add', path: devworkspaceStorageTypePath, value: currentPvcStrategy });
-        }
-      } else {
-        patch.push({
-          op: 'add',
-          path: '/spec/template/attributes',
-          value: { [DEVWORKSPACE_STORAGE_TYPE_ATTR]: currentPvcStrategy },
-        });
-        attributes = {};
-      }
-    }
-
     const openVSXURL = config.pluginRegistry?.openVSXURL || '';
     const components = cloneDeep(workspace.spec.template.components);
     if (components) {
